def pozdrav(name):
 print("Zdravo," + name)
